Management Commands — Static Media Manager v0.4 documentation

Static Media Manager v0.4 documentation

# Management Commands

- Table of Contents
- index
  modules
  next
  previous

# Management Commands

## `copy_static_media`

- Combines any files configured in STATIC_MEDIA_FILE_COMBINATIONS.
- Copies all media files configured in STATIC_MEDIA_COPY_PATHS. Compression is applied according to STATIC_MEDIA_COMPRESS_CSS and STATIC_MEDIA_COMPRESS_JS unless overridden by command-line options.
- Copies all application media unless STATIC_MEDIA_APP_MEDIA_PATH is `None`.

### Options

`-c````,` `--compresscss```
  Override the STATIC_MEDIA_COMPRESS_CSS setting and compress the css files while copying.

`-j````,` `--compressjs```
  Override the STATIC_MEDIA_COMPRESS_JS setting and compress the javascript files while copying.

`-p````,` `--purge```
  Override the STATIC_MEDIA_PURGE_OLD_FILES setting and purge all existing files in the destination before copying.